raise ImportError(
    "The 'CADET' namespace is currently an empty placeholder.\n\n"
    "For information on how to install 'CADET', see: https://cadet.github.io/\n\n"
    "- CADET-Core is distributed via conda-forge: https://anaconda.org/conda-forge/cadet\n"
    "- CADET-Python is distributed via PyPI: https://pypi.org/project/CADET-Python/\n"
)
